Durable

pub struct Durable<V> {
    pub ets: u64,
    pub leader: Option<NodeId>,
    pub decision: Option<V>,
    pub lec: Option<Started>,
    pub lep: Option<Durable<V>>,
}
Everything this stack keeps durably, as one rewritten value.

The two Option fields are the children’s slots. They are Option because a child may not have written yet, and because [Slot::write] has to be able to build this record from nothing.

Fields

ets: u64

ets.

leader: Option<NodeId>

ℓ. None before this process’s own Init has written, which is when it is ℓ0.

decision: Option<V>

decision.

lec: Option<Started>

lec’s record: (startts, start).

lep: Option<Durable<V>>

lep.ets’s record: (valts, val) and epochdecision.